@@ -18,12 +18,11 @@
 from __future__ import print_function
 
 try:
-    try:
-        from importlib.resources import read_binary as resource_bytes
-    except ImportError:
-        from pkg_resources import resource_string as resource_bytes
+    import importlib.metadata as importlib_metadata
 except ImportError:
-    VERSION = 'local'
-else:
-    VERSION = resource_bytes(
-        'germinate', 'version.txt').decode('UTF-8').rstrip('\n')
+    import importlib_metadata
+
+try:
+    VERSION = importlib_metadata.version("germinate")
+except importlib_metadata.PackageNotFoundError:
+    VERSION = "(unknown version)"
